# eea
Implementation of Extended Euclidean Algorithm, which is to calculate two integers' greatest common divisor and its linear combination from the two integers at the same time.

## Dependencies
- [numpy](https://numpy.org/)
- [numpy](https://github.com/numpy/numpy)